#!/bin/bash
#
# source: http://ftp.gnome.org/pub/gnome/sources/gnome-disk-utility/2.32/gnome-disk-utility-2.32.0.tar.bz2
#
# maintainer: gmg (monpontet.gerard@neuf.fr)
#

#------------------Set Some Variables

soft="gnome-disk-utility"
softversion="2.32.0"
arch="i486"
cpu="i686"
packageversion="70.1"

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.bz2"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

# -----------------Extract sources and get ready to build

cd $buildir
rm -rf $src
tar -xvjf $srcpkg
rm -f $dest.txz
rm -rf $dest

#------------------Set correct permissions

cd $src
chown -R root:root .
find . \
 \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
 -exec chmod 755 {} \; -o \
 \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
 -exec chmod 644 {} \;

zcat $buildir/remove_scrollkeeper_trash.diff.gz | patch -p1 --verbose
zcat $buildir/autostart-in-all-but-kde.patch.gz | patch -p1 --verbose
zcat $buildir/gdu_use_xdg-open_not_nautilus.patch.gz | patch -p1 --verbose

export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
./configure \
  --prefix=/usr \
  --sysconfdir=/etc \
  --localstatedir=/var \
  --mandir=/usr/man \
  --disable-scrollkeeper

make -j4
make install DESTDIR=$dest

find $dest | xargs file | grep -e "shared object" -e "executable" | grep ELF \
  | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

rm $dest/usr/share/applications/*.desktop
cat << EODESK > $dest//usr/share/applications/palimpsest.desktop
[Desktop Entry]
Name=Disk Utility
Name[ar]=أداة الأقراص
Name[as]=Disk Utility
Name[ast]=Utilidá de discos
Name[bg]=Инструмент за дискове
Name[bn_IN]=Disk Utility
Name[ca]=Utilitat de discs
Name[cs]=Diskový nástroj
Name[da]=Diskredskab
Name[de]=Laufwerksverwaltung
Name[el]=Εργαλείο δίσκων
Name[en_GB]=Disk Utility
Name[es]=Utilidad de discos
Name[et]=Kettautiliit
Name[eu]=Diskoen tresna
Name[fi]=Levytyökalu
Name[fr]=Utilitaire de disque
Name[ga]=Uirlis Diosca
Name[gl]=Utilidade de disco
Name[he]=תוכנית שירות הכונן
Name[hi]=डिस्क उपयोगिता
Name[hu]=Lemezkezelő
Name[it]=Gestore dischi
Name[ja]=ディスク・ユーティリティ
Name[ko]=디스크 도구
Name[ku]=Amûra Dîskan
Name[lt]=Diskų įrankis
Name[mr]=डिस्क युटिलिटी
Name[nb]=Diskverktøy
Name[pl]=Narzędzie do obsługi dysków
Name[pt]=Utilitário de Disco
Name[pt_BR]=Utilitário de unidades
Name[ro]=Utilitar de disc
Name[ru]=Дисковая утилита
Name[sl]=Diskovna orodja
Name[sr]=Управник дискова
Name[sr@latin]=Upravnik diskova
Name[sv]=Diskverktyg
Name[th]=เครื่องมือดิสก์
Name[tr]=Disk Aracı
Name[uk]=Дискова утиліта
Name[vi]=Tiện ích đĩa
Name[zh_CN]=磁盘实用工具
Name[zh_HK]=磁碟公用程式
Name[zh_TW]=磁碟公用程式
Comment=Manage Drives and Media
Comment[ar]=أدِر الأقراص ووسائط التخزين
Comment[ast]=Xestiona preseos y sofitos
Comment[bg]=Управление на устройства и носители
Comment[ca]=Gestioneu unitats i suports
Comment[cs]=Správa disků a médií
Comment[da]=Håndtering af drev og medier
Comment[de]=Verwalten von Laufwerken und Medien
Comment[el]=Διαχείριση δίσκων και μέσων
Comment[en_GB]=Manage Drives and Media
Comment[es]=Gestione dispositivos y soportes
Comment[et]=Ketaste ja andmekandjate haldamine
Comment[eu]=Kudeatu unitate eta euskarriak
Comment[fi]=Hallitse levyasemia ja medioita
Comment[fr]=Gérer les disques et les lecteurs
Comment[ga]=Bainistigh Tiomántáin agus Meáin
Comment[gl]=Xestionar novos dispositivos e medios
Comment[he]=נהל כוננים ומדיות
Comment[hi]=चालन और मीडिया प्रबंधित करें
Comment[hu]=Lemezek és adathordozók kezelése
Comment[it]=Gestisce unità e supporti
Comment[ja]=ドライブとメディアの管理
Comment[ko]=드라이브와 미디어를 관리합니다
Comment[ku]=Rêveberiya Medya û Ajokeran
Comment[lt]=Valdyti įrenginius ir laikmenas
Comment[mr]=ड्राइव्हस् व मिडीया व्यवस्थापीत करा
Comment[nb]=Håndter stasjoner og media
Comment[pl]=Zarządzanie dyskami i nośnikami
Comment[pt]=Gerir Unidades e Media
Comment[pt_BR]=Gerencie unidades e mídias
Comment[ro]=Administrează dispozitive și medii de stocare
Comment[ru]=Управление дисками и носителями
Comment[sl]=Upravljanje pogonov in medijev
Comment[sr]=Управљање дисковима и медијумима
Comment[sr@latin]=Upravljanje diskovima i medijumima
Comment[sv]=Hantera enheter och media
Comment[th]=จัดการไดรว์และสื่อ
Comment[tr]=Sürücüleri ve Ortamı Yönet
Comment[uk]=Керування дисками та змінними носіями
Comment[vi]=Quản lý đĩa và các loại vật chứa
Comment[zh_CN]=管理驱动器及媒体
Comment[zh_HK]=管理磁碟機與媒體
Comment[zh_TW]=管理磁碟機與媒體
Exec=gksu palimpsest
Icon=gnome-fs-blockdev
Terminal=false
Type=Application
StartupNotify=true
X-GNOME-DocPath=palimpsest/palimpsest.xml
Categories=Application;System;Settings;X-Zenpanel;
EODESK

mkdir -p $dest/usr/doc/$soft-$softversion $dest/usr
cp -a \
  AUTHORS COPYING INSTALL NEWS README TODO \
  $dest/usr/doc/$soft-$softversion
( cd $dest/usr/doc/$soft-$softversion ; ln -s /usr/share/gtk-doc/html/$soft html )

#-----------------Make the slack-desc files

mkdir -p $dest/install
cat << EODESC > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

                  |-----handy-ruler---------------------------------------------------|
gnome-disk-utility: gnome-disk-utility - is gnome disk tools
gnome-disk-utility:
gnome-disk-utility: gnome-disk-utility provides libraries and applications for dealing
gnome-disk-utility: with storage devices
gnome-disk-utility: 
gnome-disk-utility:
gnome-disk-utility:
gnome-disk-utility:
gnome-disk-utility:
gnome-disk-utility:
gnome-disk-utility:
EODESC

mkdir -p $dest/usr/src/$soft-$softversion
cp -a $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

#-------------------Make the packages and the md5sum

cd $dest
makepkg -l y -c n $dest.txz

cd $buildir
md5sum $package.txz > $package.md5